@@ -11,12 +11,13 @@ async def alipay(matcher: Matcher, args: Message = CommandArg()):
     amount = args.extract_plain_text().replace("元", "")
     if not amount:
         return
-    try:
-        amount = cn2an.cn2an(amount, "smart")
-    except Exception:
-        await matcher.send("错误的，请输入正确的数字")
+    if not amount.isdigit():
+        try:
+            amount = cn2an.cn2an(amount, "smart")
+        except Exception:
+            await matcher.send("错误的，请输入正确的数字")
     if 0.01 <= amount <= 999999999999.99:
-        url = f"https://mm.cqu.cc/share/zhifubaodaozhang/?money={amount}"
+        url = f"https://mm.cqu.cc/share/zhifubaodaozhang/mp3/{amount}.mp3"
         await matcher.send(MessageSegment.record(url))
     else:
         await matcher.send("数字大小超出限制，支持范围为0.01~999999999999.99")
